from setuptools import setup

setup(
    name='NlpToolkit-SentiNet',
    version='1.0.6',
    packages=['SentiNet'],
    url='https://github.com/olcaytaner/TurkishSentiNet-Py',
    license='',
    author='olcaytaner',
    author_email='olcaytaner@isikun.edu.tr',
    description='Turkish SentiNet'
)
